bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD.plot
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaARD.plot